@@ -17,8 +17,11 @@
 
 import gtweak
 from gtweak.gshellwrapper import GnomeShellFactory
-from gtweak.tweakmodel import TWEAK_GROUP_WINDOWS
-from gtweak.widgets import ListBoxTweakGroup, GSettingsComboEnumTweak, GSettingsComboTweak, GSettingsSwitchTweak, Title, GSettingsSwitchTweakValue
+from gtweak.tweakmodel import TWEAK_GROUP_WINDOWS, Tweak
+from gtweak.widgets import ListBoxTweakGroup, GSettingsComboEnumTweak, GSettingsComboTweak, GSettingsSwitchTweak, Title, GSettingsSwitchTweakValue, build_label_beside_widget
+from gtweak.utils import XSettingsOverrides
+
+from gi.repository import Gtk
 
 _shell = GnomeShellFactory().get_shell()
 _shell_loaded = _shell is not None
@@ -27,29 +30,48 @@ class ShowWindowButtons(GSettingsSwitchTweakValue):
 
     def __init__(self, name, value, **options):
         self.value = value
+        self._xsettings = XSettingsOverrides()
         GSettingsSwitchTweakValue.__init__(self,
                                            name,
                                            "org.gnome.desktop.wm.preferences",
                                            "button-layout",
                                            loaded=_shell_loaded,
                                            **options)
-        self.values=[':close',':minimize,close', ':maximize,close', ':minimize,maximize,close']
-        
     def get_active(self):
         return self.value in self.settings.get_string(self.key_name)
             
     def set_active(self, v):
         val = self.settings.get_string(self.key_name)
         if v:
-            id = self.values.index(val)
-            if id == 0:
+            if val == ":close":
                 val = val.replace(":", ":"+self.value+",")
             else:
-                val= self.values[len(self.values)-1]
+                val = ":minimize,maximize,close"
         else:
             val = val.replace(self.value+",", "")
 
         self.settings.set_string(self.key_name, val)
+        self._xsettings.set_window_buttons(val.replace(":", "menu:"))
+
+class WindowScalingFactorTweak(Gtk.Box, Tweak):
+    def __init__(self, **options):
+        Gtk.Box.__init__(self, orientation=Gtk.Orientation.HORIZONTAL)
+        Tweak.__init__(self, _("Window scaling"), _("Adjust GDK window scaling factor for HiDPI"), **options)
+
+        self._xsettings = XSettingsOverrides()
+
+        adjustment = Gtk.Adjustment(lower=1, upper=2, step_increment=1, page_increment=1)
+        w = Gtk.SpinButton()
+        w.set_adjustment(adjustment)
+        w.set_digits(0)
+        adjustment.set_value(self._xsettings.get_window_scaling_factor())
+        w.connect("value-changed", self._on_value_changed)
+
+        build_label_beside_widget(self.name, w, hbox=self)
+        self.widget_for_size_group = w
+
+    def _on_value_changed(self, adj):
+        self._xsettings.set_window_scaling_factor(adj.get_value())
 
 TWEAK_GROUPS = [ 
     ListBoxTweakGroup(TWEAK_GROUP_WINDOWS,
@@ -68,6 +90,8 @@ TWEAK_GROUPS = [
         Title(_("Titlebar Buttons"), "", uid="title-theme"),
         ShowWindowButtons(_("Maximize"), "maximize"),
         ShowWindowButtons(_("Minimize"), "minimize"),
+        Title(_("HiDPI"), "", uid="title-hidpi"),
+        WindowScalingFactorTweak(),
     )
 ]
 
