@@ -31,8 +31,9 @@ class Window(Gtk.ApplicationWindow):
         Gtk.ApplicationWindow.__init__(self,
                                        application=app)
         
-        self.set_size_request(950, 650)
+        self.set_size_request(950, 680)
         self.set_position(Gtk.WindowPosition.CENTER)
+        self.set_icon_name("gnome-tweak-tool")
         
         self.hsize_group = Gtk.SizeGroup(Gtk.SizeGroupMode.HORIZONTAL)
 
@@ -61,6 +62,7 @@ class Window(Gtk.ApplicationWindow):
         header = Gtk.Box()
 
         left_header = Gtk.HeaderBar()
+        left_header.props.show_close_button = True
         right_header = Gtk.HeaderBar()
         right_header.props.show_close_button = True
 
@@ -69,6 +71,12 @@ class Window(Gtk.ApplicationWindow):
         right_header.get_style_context().add_class("titlebar")
         right_header.get_style_context().add_class("tweak-titlebar-right")
 
+        layout_desc = Gtk.Settings.get_default().props.gtk_decoration_layout;
+        tokens = layout_desc.split(":", 2)
+        if tokens != None:
+                right_header.props.decoration_layout = ":" + tokens[1]
+                left_header.props.decoration_layout = tokens[0]
+
         self.title = Gtk.Label("")
         self.title.get_style_context().add_class("title")
         right_header.set_custom_title(self.title)
